Changes to the NE editor
------------------------

This document contains details of changes to the specification of the NE editor
that have been made since the 1st edition of the manual was printed. It was
last updated on 14 July 1999, to correspond to NE version 1.26.


Changes to version 1.26 (14-Jul-99)
-----------------------------------

1. The cl command may now take a hexadecimal string as its (optional) argument, 
for example cl x/0d/.



Changes to version 1.25 (12-Dec-97)
-----------------------------------

1. The command "ne" is a synonym for "newbuffer".

2. It is possible to compile a separate binary, in which all regular 
expressions are treated as Perl-style regular expressions, using the PCRE 
library. The "unixregexp" command is ignored, and the metacharacter in 
replacement strings with the r qualifier is $ rather than %. The version number 
(displayed at start up) ends with "P" if Perl-style regular expressions are in 
use. You can also tell which binary you have got by entering an invalid regular
expression. The normal binary tells you whether unixregexp is set or not; the
Perl-style binary says nothing after the error message.



Changes for DOS NE version 1.23 (14-Dec-94)
-------------------------------------------

The Ctrl-Left and Ctrl-Right arrows are now bound to word back and word forward
respectively by default; this ties in with PC conventions.



Changes to version 1.20 (10-Oct-94)
-----------------------------------

1. On some systems (Unix systems in particular) NE exits from its screen-
handling mode before obeying a system command introduced with *. This means
that, when reading a line of NE commands afterwards, the normal line-by-line
input conventions are in force instead of those used when in screen mode, and
NE's command line history mechanism is not available. To indicate this, the
prompt that is given in these circumstances has been changed to "NE:" instead
of "NE>". Not all implementations of NE operate in this way; for those that
don't the prompt after a * command will still be "NE>".

2. The {WORD-LEFT} and {WORD-RIGHT} keystrokes no longer stop at individual
non-word characters. They now stop at the marked points in the following
example:

  a,bc,d
  ^ ^  ^
Previously they would have stopped at the comma characters as well.

3. The {WORD-LEFT} and {WORD-RIGHT} keystrokes now operate when reading in a
command line in screen mode.

4. Two new keystrokes called {DELETE-TO-WORD-LEFT} and {DELETE-TO-WORD-RIGHT}
have been implemented. There are also corresponding commands DTWL and DTWR
commands. The keystrokes are not associated with any keypresses by default; the
mnemonic names used in the KEY command to set them up are "dtwl" and "dtwr".

The DTWR operation deletes characters to the right in the current line,
starting from the character at the cursor, and ending at the last character
before the next position in which a {WORD-RIGHT} cursor-moving operation would
stop. In other words, it deletes everthing from the current position to the
start of the next word.

The DTWL operation deletes characters to the left in the current line, starting
at the character preceding the cursor position, and ending with the character
at which a {WORD-LEFT} cursor-moving operation would stop. In other words, it
deletes back to the start of the previous word.

Note that, unlike the {WORD-LEFT} and {WORD-RIGHT} keystrokes, these operations
never move to a different current line. If issued at the start of end of a
line (respectively), they have no effect. They do, however, operate when NE is
reading a line of commands in screen mode.

5. There is a new command called PBUFFER, which operates like the BUFFER
command, but cycles through the buffers in the opposite order. By default,
{KEYSTRING-11} is set up to obey PBUFFER.

6. NE has in the past been very conservative in choosing which characters it is
prepared to display in screen mode. It has stuck to the printable ASCII
characters with codes in the range 32-126, and displayed any other data
characters as question marks. On some systems, however, so-called "top-bit-set"
or "eightbit" characters with codes in the range 160-255 are meaningful, and
are used for additional graphics.

A new command called EIGHTBIT controls whether NE displays these additional
characters or not. It can be called with either of the argument words ON or
OFF; if called with no argument, it changes to the opposite state.

The default setting depends on the NE implementation. On Unix systems, the
display of these characters depends on the terminal being used, and since this
cannot be predicted, the default setting is OFF.

7. The following additional escape combinations have been added to those
recognized by NE when interpreting regular expressions in "Unix style":

  \d   matches a decimal digit
  \D   matches a character which is not a decimal digit
  \s   matches a white space character (space or tab)
  \S   matches a character which is not a white space character
  \w   matches a "word" character (as defined by the WORD command)
  \W   matches a character which is not a "word" character

8. The command SHOW WORDCHARS causes NE to display the list of characters that
are set as being "word" characters.

9. The command SHOW SETTINGS causes NE to display the state of a number of
option settings, such as the eightbit character display option. The values for
the readonly and prompt options apply to the current buffer only.

10. It is now possible to specify "-" as the file name for the -with and -ver
command line keys, as well as for the -from and -to keys. The effect of "-with -"
is to cause editing commands to be read from the standard input (which is the
default), but in line-by-line mode. The effect of "-ver -" is likewise to cause
verification output to be written to the standard output. (This is also the
default - the syntax is really provided just for consistency.)

The preferred method of calling NE from within a Unix shell script to edit a
file using inline editing commands is now thus:

  ne somefile -with - <<End
  <editing commands>
  End

NE will diagnose an error if both -from and -with are specified (explicitly or
implicitly) as the standard input. This also happens if -to and -ver are both
specified explicitly as the standard output. If only -to is specified as the
standard output, the default for -ver is changed to the standard error stream.

11. Keyboard interrupts are now recognized while scanning through large files
as a result of the {SCROLL-BOTTOM} keystroke, and also while reading a file as
a result of obeying the command M* on a partially-read input file.


Changes for DOS NE version 1.20
-------------------------------

1. Wildcard <from> file specification now works on the MS-DOS version, 
as do multiple <from> files; thus it is now possible (as on the Unix 
version) to type:

ne f*.doc

ne file.1 file.2 file.3

to place the matching files in different buffers; up to 9 files can 
be specified in this way. If the wildcard matches more than 9 files 
only the first 9 encountered in the directory are placed in buffers - 
the rest are ignored.

2. Bug fixes: Shift-Ctrl-_ was not recognised as ^_

              Main <Enter/Return> key now definable as the special 
              key 'ret'

              SET AUTOVSCROLL <n> with <n> greater than 1 did not 
              work

****
